@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.40 2003/05/26 17:43:13 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.44 2003/07/08 15:17:08 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -237,8 +237,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {
     N_("*"),
     N_("Multiply"),
-    { 0,            0,               0,     0,      0 },
-    { GDK_asterisk, GDK_KP_Multiply, GDK_x, GDK_R6, 0 },
+    { GDK_SHIFT_MASK, 0,               0,     0,      0 },
+    { GDK_asterisk,   GDK_KP_Multiply, GDK_x, GDK_R6, 0 },
     '*',
     M_NONE,
     do_calc
@@ -978,7 +978,7 @@ doerr(char *errmes)
     }
     STRCPY(v->display, errmes);
     set_display(v->display);
-    v->error = 1;
+    set_error_state(TRUE);
     beep();
 }
 
